from .Colloquial_Converter import Colloquial_Converter
from .Diacritizer import Diacritizer
from .Named_Entity_Recognizer import Named_Entity_Recognizer
from .Parser import Parser
from .Part_of_Speech_Tagger import Part_of_Speech_Tagger
from .SARF import SARF
from .Speller import Speller
from .Transliteration import Transliteration